@@ -318,7 +318,7 @@ class Loaf:
             setValues = ""
             for i in range(len(columns)):
                 setValues += f"{columns[i]} = {parse(values[i])}, "
-            setValues = finalColumns[:-2]
+            setValues = setValues[:-2]
         else:
             raise Exception("Invalid COLUMNS or VALUES type.")
         self.query(f"UPDATE {table} SET {setValues} WHERE {where}")
